@@ -12,9 +12,7 @@
 
 #include "pg_squeeze.h"
 
-#if PG_VERSION_NUM >= 130000
 #include "access/heaptoast.h"
-#endif
 #include "executor/executor.h"
 #include "replication/decode.h"
 #include "utils/rel.h"
@@ -121,11 +119,6 @@ decode_concurrent_changes(LogicalDecodingContext *ctx,
 {
 	DecodingOutputState *dstate;
 	ResourceOwner resowner_old;
-#if PG_VERSION_NUM < 130000
-	/* Workaround for XLogBeginRead() in setup_decoding(). */
-	static	bool	first_time = true;
-	XLogRecPtr	startptr;
-#endif
 
 	/*
 	 * Invalidate the "present" cache before moving to "(recent) history".
@@ -153,21 +146,7 @@ decode_concurrent_changes(LogicalDecodingContext *ctx,
 			char	   *errm = NULL;
 			XLogRecPtr	end_lsn;
 
-#if PG_VERSION_NUM < 130000
-			if (first_time)
-			{
-				startptr = MyReplicationSlot->data.restart_lsn;
-				first_time = false;
-			}
-			else
-				startptr = InvalidXLogRecPtr;
-#endif
-
-			record = XLogReadRecord(ctx->reader,
-#if PG_VERSION_NUM < 130000
-									startptr,
-#endif
-									&errm);
+			record = XLogReadRecord(ctx->reader, &errm);
 			if (errm)
 				elog(ERROR, "%s", errm);
 
@@ -238,7 +217,6 @@ apply_concurrent_changes(DecodingOutputState *dstate, Relation relation,
 
 	/* TupleTableSlot is needed to pass the tuple to ExecInsertIndexTuples(). */
 	slot = MakeSingleTupleTableSlot(dstate->tupdesc, &TTSOpsHeapTuple);
-	iistate->econtext->ecxt_scantuple = slot;
 
 	/* A slot to fetch tuples from identity index. */
 	ind_slot = table_slot_create(relation, NULL);
@@ -367,8 +345,13 @@ apply_concurrent_changes(DecodingOutputState *dstate, Relation relation,
 			 * the reason to increment the counter). However, heap_update()
 			 * does require CommandCounterIncrement().
 			 */
+#if PG_VERSION_NUM >= 180000
+			scan = index_beginscan(relation, iistate->ident_index,
+								   GetActiveSnapshot(), NULL, nkeys, 0);
+#else
 			scan = index_beginscan(relation, iistate->ident_index,
 								   GetActiveSnapshot(), nkeys, 0);
+#endif
 
 			index_rescan(scan, key, nkeys, NULL, 0);
 
@@ -552,7 +535,6 @@ get_index_insert_state(Relation relation, Oid ident_index_id)
 
 	result = (IndexInsertState *) palloc0(sizeof(IndexInsertState));
 	estate = CreateExecutorState();
-	result->econtext = GetPerTupleExprContext(estate);
 
 	result->rri = (ResultRelInfo *) palloc(sizeof(ResultRelInfo));
 	InitResultRelInfo(result->rri, relation, 0, 0, 0);
